==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/blocktype/inbox/lang/en.utf8/blocktype.inbox.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-inbox
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'My Inbox';
$string['description'] = 'Display a selection of your recent inbox messages';
$string['messagetypes'] = 'Message types to display';
$string['maxitems'] = 'Maximum number of items to display';
$string['maxitemsdescription'] = 'Between 1 and 100';
$string['More'] = 'More';
$string['nomessages'] = 'No messages';
$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/blocktype/inbox/lang/en.utf8/blocktype.inbox.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-inbox
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'My inbox';
$string['description'] = 'Display a selection of your recent inbox messages';
$string['messagetypes'] = 'Message types to display';
$string['maxitems'] = 'Maximum number of items to display';
$string['maxitemsdescription'] = 'Between 1 and 100';
$string['More'] = 'More';
$string['nomessages'] = 'No messages';
$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';
